replace_scc_section

Function replace_scc_section 

pub fn replace_scc_section(existing: &str, new_section: &str) -> String
Replace a managed section delimited by an explicit marker pair. replace_scc_section is this function with the legacy shared markers.