run_agent_benchmark

Function run_agent_benchmark 

pub fn run_agent_benchmark(
    cmd: &str,
    min_files: f64,
) -> Result<AgentBenchSummary, String>
scc bench agent --cmd "<command>" — the command receives the task goal via the SCC_GOAL env var and the repo path as its working directory (like claude -p "$SCC_GOAL" or codex exec -- "$SCC_GOAL").